@@ -1,3 +1,5 @@
+{-# LANGUAGE CPP #-}
+
 {-|
   WAI (Web Application Interface) Application for static files and CGI.
 -}
@@ -29,12 +31,14 @@ module Network.Wai.Application.Classic (
   , module Network.Wai.Application.Classic.Path
   -- * Misc
   , redirectHeader
+  , hostPort
   ) where
 
 import Network.Wai.Application.Classic.CGI
+import Network.Wai.Application.Classic.Def
 import Network.Wai.Application.Classic.File
+import Network.Wai.Application.Classic.Header
 import Network.Wai.Application.Classic.Path
 import Network.Wai.Application.Classic.Redirect
 import Network.Wai.Application.Classic.RevProxy
 import Network.Wai.Application.Classic.Types
-import Network.Wai.Application.Classic.Def
